(** Clauses defining intruder deduction rules *)

open Clause;;


(** {b CONS} *)

(** empty_list *)
val intruder_empty : clause

(** pairing *)
val intruder_P : clause

(** left projection *)
val intruder_P1 : clause

(** right projection *)
val intruder_P2 : clause


(** {b  APP} *)

(** application of known function symbol *)
val intruder_F : Symbols.eva_symbol_list -> clause list

(** inversion of known function symbol *)
val intruder_F1 : Symbols.eva_symbol_list -> clause list


(** {b CRYPT} *)

(** we assume that the intruder knows all the encryption algos
  (symmetric and asym) *)

(** encryption with known key *)
val intruder_E : clause

(** decryption with constant symmetric key *)
val intruder_Dcst : Symbols.eva_symbol_list -> clause list

(** decryption with symmetric key which is 
  the intruder's name (USEFUL ?). *)
val intruder_DI : Symbols.eva_symbol_list -> clause

(** decryption with symmetric key which is 
  a constant declared as value *)
val intruder_Dval : Symbols.eva_symbol_list -> clause list

(** decryption with symmetric key made of CONS *)
val intruder_DCONS : Symbols.eva_symbol_list -> clause

(** decryption with symmetric key made of APP
  with function symbol which is not a asymetric key. *)
val intruder_DAPP : Symbols.eva_symbol_list -> clause list

(** decryption with symmetric key made of CRYPT *)
val intruder_DCRYPT : clause

(** we assume no use of SIGN *)

(** decryption with asymmetric key made of APP with key symbol
  or made of a singleton list containing an APP with key symbol *)
val intruder_DA : Symbols.eva_symbol_list -> clause list

(** {b coercion} *)

(** coercion functions *)
val intruder_coerce : Symbols.eva_symbol_list -> clause list

(** inversion of coercion functions *)
val intruder_coerce1 : Symbols.eva_symbol_list -> clause list

(** list of clauses for the intruder deduction rules *)
val rules : Symbols.eva_symbol_list -> clause list

